@@ -1,5 +1,6 @@
 """Admin models."""
 
+from .alarm import Alarm
 from .alias import Alias, AliasRecipient
 from .base import AdminObject
 from .domain import Domain
@@ -8,6 +9,7 @@ from .mailbox import Mailbox, MailboxOperation, Quota, SenderAddress
 from .mxrecord import DNSBLResult, MXRecord
 
 __all__ = [
+    "Alarm",
     "AdminObject",
     "Alias",
     "AliasRecipient",
